@@ -1,6 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2002 Jean-Baptiste Mardelle <bj@altern.org>
-    SPDX-FileCopyrightText: 2007, 2008, 2009, 2010, 2011, 2012, 2013 Rolf Eike Beer <kde@opensource.sf-tec.de>
+    SPDX-FileCopyrightText: 2007-2022 Rolf Eike Beer <kde@opensource.sf-tec.de>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -59,7 +59,7 @@ class KeysManager : public KXmlGuiWindow
 
 public:
     explicit KeysManager(QWidget *parent = nullptr);
-    ~KeysManager() override;
+    ~KeysManager() override = default;
 
     KGpgItemModel *getModel();
 
